==> core-react-0.8.0.tgz: package/es/Upload/FileList.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Icon from '../Icon';


var FileList = /*#__PURE__*/function (_Component) {
  _inherits(FileList, _Component);

  function FileList() {
    _classCallCheck(this, FileList);

    return _possibleConstructorReturn(this, _getPrototypeOf(FileList).apply(this, arguments));
  }

  _createClass(FileList, [{
    key: "handleClick",
    value: function handleClick(item) {
      this.props.onRemove(item);
    }
  }, {
    key: "render",
    value: function render() {
      var _this = this;

      return React.createElement("div", {
        className: "".concat("waui", "-upload__filelist")
      }, this.props.data.map(function (item, index) {
        return React.createElement("div", {
          key: index,
          className: "".concat("waui", "-upload__filelist_row")
        }, React.createElement("span", null, item.name), React.createElement("span", null, item.percent, "%"), React.createElement(Icon, {
          type: "upload",
          style: {
            display: item.state === 0 ? '' : 'none'
          }
        }), React.createElement(Icon, {
          type: "check-circle",
          style: {
            paddingRight: '10px',
            color: 'green',
            display: item.state === 1 ? '' : 'none'
          }
        }), React.createElement(Icon, {
          type: "times-circle",
          style: {
            paddingRight: '10px',
            color: 'red',
            display: item.state === 2 ? '' : 'none'
          }
        }), React.createElement(Icon, {
          type: "trash",
          style: {
            color: 'gray',
            cursor: 'pointer'
          },
          onClick: _this.handleClick.bind(_this, item)
        }));
      }));
    }
  }]);

  return FileList;
}(Component);

FileList.propTypes = {
  data: PropTypes.array,
  onRemove: PropTypes.func
};
export default FileList;

==> core-react-0.8.2.tgz: package/es/Upload/FileList.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Icon from '../Icon';


var FileList = /*#__PURE__*/function (_Component) {
  _inherits(FileList, _Component);

  function FileList() {
    _classCallCheck(this, FileList);

    return _possibleConstructorReturn(this, _getPrototypeOf(FileList).apply(this, arguments));
  }

  _createClass(FileList, [{
    key: "handleClick",
    value: function handleClick(item) {
      this.props.onRemove(item);
    }
  }, {
    key: "render",
    value: function render() {
      var _this = this;

      return (/*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-upload__filelist")
        }, this.props.data.map(function (item, index) {
          return (/*#__PURE__*/React.createElement("div", {
              key: index,
              className: "".concat("waui", "-upload__filelist_row")
            }, /*#__PURE__*/React.createElement("span", null, item.name), /*#__PURE__*/React.createElement("span", null, item.percent, "%"), /*#__PURE__*/React.createElement(Icon, {
              type: "upload",
              style: {
                display: item.state === 0 ? '' : 'none'
              }
            }), /*#__PURE__*/React.createElement(Icon, {
              type: "check-circle",
              style: {
                paddingRight: '10px',
                color: 'green',
                display: item.state === 1 ? '' : 'none'
              }
            }), /*#__PURE__*/React.createElement(Icon, {
              type: "times-circle",
              style: {
                paddingRight: '10px',
                color: 'red',
                display: item.state === 2 ? '' : 'none'
              }
            }), /*#__PURE__*/React.createElement(Icon, {
              type: "trash",
              style: {
                color: 'gray',
                cursor: 'pointer'
              },
              onClick: _this.handleClick.bind(_this, item)
            }))
          );
        }))
      );
    }
  }]);

  return FileList;
}(Component);

FileList.propTypes = {
  data: PropTypes.array,
  onRemove: PropTypes.func
};
export default FileList;
